==> glb-0.0.16.tar.gz: glb-0.0.16/glb/v1/api/balancer_balancer_name_backends.py <==
# -*- coding: utf-8 -*-
from flask import g

from . import Resource
from glb.core.errors import notfounderror
from glb.models.balancer import Balancer as BalancerModel


class BalancerBalancerNameBackends(Resource):

    def get(self, balancer_name):
        balancer = BalancerModel.retrieve(balancer_name)
        if balancer:
            return balancer.backends, 200, None
        else:
            return notfounderror()

    def post(self, balancer_name):
        balancer = BalancerModel.retrieve(balancer_name)
        if balancer:
            res = balancer.set_backends(g.json, 'add')
            return res, 201, None
        else:
            return notfounderror()

    def put(self, balancer_name):
        balancer = BalancerModel.retrieve(balancer_name)
        if balancer:
            res = balancer.set_backends(g.json, 'update')
            return res, 200, None
        else:
            return notfounderror

    def delete(self, balancer_name):
        balancer = BalancerModel.retrieve(balancer_name)
        print 'ssss'
        if balancer:
            address = g.args.get('address', '')
            port = int(g.args.get('port', 0))
            val = {}
            if g.args.get('tag', None) is None:
                action = 'delete'
                val = dict(address=address,
                           port=port)
            else:
                action = 'delete_by_tag'
            res = balancer.set_backends(val, action)
            return res, 200, None
        else:
            return notfounderror

==> glb-0.0.54.tar.gz: glb-0.0.54/glb/v1/api/balancer_balancer_name_backends.py <==
# -*- coding: utf-8 -*-
from flask import g

from . import Resource
from glb.core.errors import notfounderror
from glb.models.balancer import Balancer as BalancerModel


class BalancerBalancerNameBackends(Resource):

    def get(self, balancer_name):
        balancer = BalancerModel.retrieve(balancer_name)
        if balancer:
            return balancer.backends, 200, None
        else:
            return notfounderror()

    def post(self, balancer_name):
        balancer = BalancerModel.retrieve(balancer_name)
        if balancer:
            res = balancer.functions('add_backends')(g.json)
            return res, 201, None
        else:
            return notfounderror()

    def put(self, balancer_name):
        balancer = BalancerModel.retrieve(balancer_name)
        if balancer:
            res = balancer.functions('update_backends')(g.json)
            return res, 200, None
        else:
            return notfounderror

    def delete(self, balancer_name):
        balancer = BalancerModel.retrieve(balancer_name)
        if balancer:
            cid = g.args.get('cid', None)
            addr = g.args.get('address', '')
            port = int(g.args.get('port', 0))
            tag = g.args.get('tag', None)
            res = False
            if cid:
                res = balancer.functions('delete_backend_by_cid')(cid)
            if addr and port:
                res = balancer.functions('delete_backend_by_addr_port')(addr, port)
            if tag:
                res = balancer.functions('delete_backend_by_tag')(tag)
            return res, 200, None
        else:
            return notfounderror
